#version 150

uniform sampler2D DiffuseSampler;

in vec2 texCoord;
in vec2 oneTexel;

uniform vec2 InSize;
uniform float Time;
uniform float PI = 3.141592653;

out vec4 fragColor;

void main() {
    vec3 CoordX = texCoord.x * vec3(1.0);
    vec3 CoordY = texCoord.y * vec3(1.0);

    float off = Time * PI * 2.0;
    CoordX += vec3(-8.0, 0.0, 2.0) * sin(off) * oneTexel.x;
    CoordY += vec3(0.0, -8.0, 2.0) * cos(off) * oneTexel.y;

    float RedValue   = texture(DiffuseSampler, vec2(CoordX.x, CoordY.x)).r;
    float GreenValue = texture(DiffuseSampler, vec2(CoordX.y, CoordY.y)).g;
    float BlueValue  = texture(DiffuseSampler, vec2(CoordX.z, CoordY.z)).b;

    vec3 col = vec3(RedValue, GreenValue, BlueValue);
    float luma = dot(col, vec3(0.3, 0.59, 0.11));
    vec3 chroma = (col - luma) * (1.5 + sin(off) * 0.5);

    fragColor = vec4(luma + chroma, texture(DiffuseSampler, texCoord).a);
}
